#
# spec file for package python-colorcet
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-colorcet
Version:        3.0.1
Release:        2.1
Summary:        Collection of perceptually uniform colormaps
License:        CC-BY-4.0
URL:            https://github.com/bokeh/colorcet
Source:         https://files.pythonhosted.org/packages/source/c/colorcet/colorcet-%{version}.tar.gz
BuildRequires:  %{python_module param >= 1.7.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyct >= 0.4.4}
BuildRequires:  %{python_module setuptools >= 30.3.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-param >= 1.7.0
Requires:       python-pyct >= 0.4.4
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
colorcet is a collection of perceptually uniform colormaps
for use with Python plotting programs like bokeh, matplotlib,
holoviews, and datashader.

%prep
%setup -q -n colorcet-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/colorcet
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative colorcet

%postun
%python_uninstall_alternative colorcet

%files %{python_files}
%doc README.md
%license LICENSE.txt
%python_alternative %{_bindir}/colorcet
%{python_sitelib}/colorcet
%{python_sitelib}/colorcet-%{version}.dist-info

%changelog
* Fri May  9 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Mon Oct  3 2022 Arun Persaud <arun@gmx.de>
- update to version 3.0.1:
  * Update to work with matplotlib=3.6 (#90)
  * Fix holoviews opts deprecation warning (#94)
  * Add support for Python 3.10 (#81)
  * Remove windows 3.6 case from test suite due to lack of mamba
    support (#94)
  * Remove Param dependency (#84)
  * Improve installation instructions (#92)
* Mon Sep 19 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.0.0:
  * New features:
    + Added new upstream colormaps (#65):
    o Rainbow: rainbow_bgyr_10_90_c83 (called rainbow4, a much
    closer match to Jet's color range than rainbow while remaining
    perceptually uniform)
    o Linear: linear_kbgoy_20_95_c57 (called gouldian, an improved
    version of Matlab's parula colormap), linear_kbgyw_10_98_c63
    o Cyclic: circle_mgbm_67_c31, circle_mgbm_67_c31_s25,
    cyclic_bgrmb_35_70_c75, cyclic_bgrmb_35_70_c75_s25,
    cyclic_isoluminant, cyclic_mybm_20_100_c48,
    cyclic_mybm_20_100_c48_s25, cyclic_mygbm_50_90_c46,
    cyclic_mygbm_50_90_c46_s25, cyclic_rygcbmr_50_90_c64,
    cyclic_rygcbmr_50_90_c64_s25, cyclic_wrkbw_10_90_c43,
    cyclic_wrkbw_10_90_c43_s25, cyclic_ymcgy_60_90_c67,
    cyclic_ymcgy_60_90_c67_s25
    o Colorblind-safe:
    diverging_linear_protanopic_deuteranopic_bjy_57_89_c34,
    linear_protanopic_deuteranopic_kbw_5_95_c34,
    linear_protanopic_deuteranopic_kyw_5_95_c49,
    linear_tritanopic_kcw_5_95_c22, linear_tritanopic_krw_5_95_c46
    + CI fixes and improvements, including testing for python 3.9
    (#71, #72, #75, #77)
    + Clarified docs to indicate that all maps have an original
    list-of-numeric-triples form, typically but not always with a
    long name, that all those starting with b_ are Bokeh colormaps
    in hex format, and that only the subset of shorter names that
    are aliases for longer names are Bokeh colormaps (as some other
    original list names like glasbey_bw just happen to be short
    (#79)
  * Compatibility:
    + For categorical (Glasbey) maps, now uses a Matplotlib
    ListedColormap (with distinct colors) instead of a
    LinearSegmentedColormap (discrete approximation to a continuous
    map) (#79)
* Sat Jan 30 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more explicit in %%files section
- update to version 2.0.6, 2.0.5, 2.0.4, 2.0.3:
  * Minor release primarily to update PyPI classifier to show that the
    license is not proprietary. Also added some docstrings and usage
    examples, and updated the swatch function to work with both list
    and tuple colormaps.
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Sep 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.2:
  * Typo fixes in metadata and small fixes only
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to version 2.0.1
  * Small fixes with sorting and names
  * Fixing issue with aspect in bokeh
  * Making things faster
  * Adding new color sets with new aliases
  * Adding console script
  * Added Glasbey 256-color categorical colormaps
  * Updated to use pyct, pyctdev, nbsite
  * Fixed broken links to images
  * Added logo
* Thu May  3 2018 toddrme2178@gmail.com
- Update to version 1.0.0
  + Minor update improving compatibility and ease of use:
  * Added attribute access for colormap and palette dictionaries
    for convenience (PR #5)
  * Pulled out the subset of colormaps that have readable names
    into the cm_n and palette_n dictionaries to make it simpler
    to use them in GUI widgets selecting colormaps
  * Improved Python2/Python3 compatibility, now supporting Python 2.7, 3.4, 3.5, and 3.6.
  + Minor backwards compatibility issue:
  * Renamed inferno to bmy to avoid confusion with matplotlib.
- Use %%license tag
* Fri Aug 18 2017 toddrme2178@gmail.com
- Initial version
